@@ -3,7 +3,7 @@ import time
 import imghdr
 import shutil
 import requests
-from .scala import *
+from .scalascript import *
 import xml.etree.ElementTree as ET
 
 
